The ``klio`` Library
====================

.. image:: https://img.shields.io/pypi/v/klio?color=%2300aa55&label=klio
   :target: https://pypi.org/project/klio
   :alt: Latest version of klio on PyPI

.. image:: https://github.com/spotify/klio/workflows/klio%20unit%20tests/badge.svg
   :target: https://github.com/spotify/klio/actions?query=workflow%3A%22klio+unit+tests%22
   :alt: Status of klio unit tests

.. start-klio-lib-intro

The library for implementing Klio-ified Apache Beam transforms with `decorators <https://docs.klio.io/en/latest/userguide/pipeline/utilities.html>`_, `helper transforms <https://docs.klio.io/en/latest/userguide/pipeline/transforms.html>`_, and leverage Klio's `message-handling logic <https://docs.klio.io/en/latest/userguide/pipeline/message.html>`_.

As the ``klio`` library is **not** meant to be installed directly, check out the `installation guide <https://docs.klio.io/en/latest/quickstart/installation.html>`_ for how to setup installation.
There is also the `user guide <https://docs.klio.io/en/latest/userguide/index.html>`_ and the `API documentation <https://docs.klio.io/en/latest/reference/lib/index.html>`_ for more information.
